@@ -169,8 +169,10 @@ sub load {
     return 1 unless -f conffile;
 
     # load YAML
-    confess "Configuration file found but YAML is not installed"
-      unless Dancer::ModuleLoader->load('YAML');
+    my ( $result, $error ) = Dancer::ModuleLoader->load('YAML');
+    if ( not $result ) {
+        confess "Configuration file found but could not load YAML: $error";
+    }
 
     if (!$_LOADED{conffile()}) {
         load_settings_from_yaml(conffile);
@@ -491,6 +493,8 @@ B<core>, B<debug>, B<warning> or B<error>.
 
 =item B<debug> : all messages are logged
 
+=item B<info> : only info, warning and error messages are logged
+
 =item B<warning> : only warning and error messages are logged
 
 =item B<error> : only error messages are logged
