@@ -19,6 +19,8 @@ use vars qw(@EXPORT);
   plugin_setting
   register_hook
   execute_hooks
+  execute_hook
+  plugin_args
 );
 
 sub register($&);
@@ -27,6 +29,8 @@ my $_keywords = {};
 
 sub add_hook { Dancer::Hook->new(@_) }
 
+sub plugin_args { (undef, @_) }
+
 sub plugin_setting {
     my $plugin_orig_name = caller();
     (my $plugin_name = $plugin_orig_name) =~ s/Dancer::Plugin:://;
@@ -39,6 +43,13 @@ sub register_hook {
 }
 
 sub execute_hooks {
+    Dancer::Deprecation->deprecated(reason => "use 'execute_hook'",
+                                    version => '1.3098',
+                                    fatal => 0);
+    Dancer::Factory::Hook->instance->execute_hooks(@_);
+}
+
+sub execute_hook {
     Dancer::Factory::Hook->instance->execute_hooks(@_);
 }
 
@@ -205,6 +216,21 @@ for B<Dancer::Plugin::Foo::Bar>, use:
     "Foo::Bar":
       key: value
 
+
+=item B<plugin_args>
+
+To easy migration and interoperability between Dancer 1 and Dancer 2
+you can use this method to obtain the arguments or parameters passed
+to a plugin-defined keyword. Although not relevant for Dancer 1 only,
+or Dancer 2 only, plugins, it is useful for universal plugins.
+
+  register foo => sub {
+     my ($self, @args) = plugin_args(@_);
+     ...
+  }
+
+Note that Dancer 1 will return undef as the object reference.
+
 =back
 
 =head1 AUTHORS
